@@ -3,6 +3,8 @@ import os, sys
 
 import xml.etree.ElementTree as ET
 
+from manafa.utils.Logger import log, LogSeverity
+
 
 class PowerProfile(object):
 	"""Stores information regarding devices' power profile xml file.
@@ -93,30 +95,48 @@ class PowerProfile(object):
 			fst_pair: before value.
 			snd_pair: after value.
 		"""
-		profile_speeds = self.components["cpu"]["speeds"] if "speeds" in self.components["cpu"]else self.components["cpu"]["core_speeds"]
-		profile_currents = self.components["cpu"]["active"] if ("speeds" in self.components["cpu"] and isinstance(self.components["cpu"]["active"], list)) else self.components["cpu"]["core_power"]
+		profile_speeds = self.components["cpu"]["speeds"] if "speeds" in self.components["cpu"] \
+			else self.components["cpu"]["core_speeds"] if 'core_speeds' in self.components["cpu"] \
+				else self.components["cpu"]["speeds"] if 'speeds' in self.components['cpu'] else None
 
-		if isinstance(profile_speeds, dict):
-			# select respective cluster of core_id	
+		profile_currents = self.components["cpu"]["active"] if ("speeds" in self.components["cpu"]
+						and 'active' in self.components['cpu'] and isinstance(self.components["cpu"]["active"], list))\
+															else self.components["cpu"]["core_power"] \
+																if 'core_power' in self.components['cpu'] else None
+		if profile_currents is None or isinstance(self.components["cpu"]["active"], dict):
+			if f'cluster{core_id}' in self.components["cpu"]["active"]:
+				profile_currents = self.components["cpu"]["active"][f'cluster{core_id}']
+			else:
+				#just
+				profile_currents = list(self.components["cpu"]["active"].items())[0][1]
+		if profile_speeds is None or isinstance(profile_speeds, dict):
+			# select respective cluster of core_id
 			core_r = core_id + 1
 			cluster_cores = self.components["cpu"]["clusters"]["cores"]
+			if len(cluster_cores) == 1 and len(cluster_cores) <= core_id:
+				log("The current power profile is probably incomplete. "
+					"The reported values for CPU energy might not be accurate",
+					log_sev=LogSeverity.ERROR)
+				profile_speeds = self.components["cpu"]["core_speeds"]["cluster0"] if 'core_speeds' in \
+																						   self.components["cpu"] else \
+				self.components["cpu"]["speeds"]["cluster0"]
 			for i, ncores in enumerate(cluster_cores):
 				if core_r > ncores:
 					core_r = core_r - ncores
 				else:
-					profile_speeds = self.components["cpu"]["core_speeds"]["cluster%d" % i]
-					profile_currents = self.components["cpu"]["core_power"]["cluster%d" % i]
+					profile_speeds = self.components["cpu"]["core_speeds"]["cluster%d" % i] \
+						if 'core_speeds' in self.components["cpu"] else self.components["cpu"]["speeds"]["cluster%d"%i]
 					break
 		mini_fr = 0
 		freq = 0
 		# find adequate freq
 		for i, f in enumerate(profile_speeds):
-			if f >= core_freq:
+			if float(f) >= core_freq:
 				freq = i
 				break
 			mini_fr = i
-		fst_pair = (profile_speeds[mini_fr], profile_currents[mini_fr])
-		snd_pair = (profile_speeds[freq], profile_currents[freq])
+		fst_pair = (float(profile_speeds[mini_fr]), float(profile_currents[mini_fr]))
+		snd_pair = (float(profile_speeds[freq]), float(profile_currents[freq]))
 		return fst_pair, snd_pair
 
 
