@@ -23,22 +23,33 @@ def convertBatStatTimeToTimeStamp(batstattime,timezone="EST"):
 	#d= pst.localize(d1)
 	#return time.mktime(d.timetuple())
 
-def batStatResetTimeToTimeStamp(matime, timezone="UTC"):
-	d1 =datetime.datetime.strptime(matime, '%Y-%m-%d-%H-%M-%S')
-	pst = pytz.timezone(timezone)
-	d= pst.localize(d1)
+
+def batStatResetTimeToTimeStamp(matime, timezone="UTC", default_tz="UTC"):
+	cv_timezone = convert_to_pytz_timezone(timezone, default_tz)
+	d1 = datetime.datetime.strptime(matime, '%Y-%m-%d-%H-%M-%S')
+	pst = pytz.timezone(cv_timezone)
+	d = pst.localize(d1)
 	return time.mktime(d.timetuple())
 
 
-def convertDateToTimeStamp(date,timezone="EST"):
+def convertDateToTimeStamp(date, timezone="EST"):
 	local = pytz.timezone(timezone)
 	#time = time.mktime(datetime.datetime.strptime(s, "%d/%m/%Y").timetuple())
 	return time
 	#return None
 
+
 def epochToDate(ts):
 	return time.ctime(ts)
 
+
+def convert_to_pytz_timezone(tz_date, default_tz="EST"):
+	if tz_date == "WEST":
+		return "WET"
+	elif tz_date == "CEST":
+		return "LMT"
+	return default_tz
+
 #x="2020-11-17-12-06-18"
 #z = batStatResetTimeToTimeStamp(x)
 #print(z)
